@@ -39,7 +39,7 @@ class DPObjectRef:
     _url: URL = "<local resource>"
     _dto: t.Optional[Munch] = None
 
-    list_fields: t.List[str] = ["name", "web_url"]
+    list_fields: t.List[str] = ["name", "web_url", "group"]
 
     @property
     def dto(self) -> t.Optional[Munch]:
@@ -89,19 +89,18 @@ class DPObjectRef:
             self.url = dto.id
 
     @classmethod
-    def get(cls: Type[U], name: str, owner: Optional[str] = None, version: Optional[str] = None) -> U:
+    def get(cls: Type[U], name: str, owner: Optional[str] = None) -> U:
         """
         Lookup and retrieve an object from the Datapane Server by its name
 
         Args:
             name: The name of the object, e.g. `my-blob 3`
             owner: The owner of the object, e.g. `fred`
-            version: The version of the object (optional, defaults to latest)
 
         Returns:
             The object if found
         """
-        res = Resource(f"{cls.endpoint}/lookup/").get(name=name, owner=owner, version=version)
+        res = Resource(f"{cls.endpoint}/lookup/").get(name=name, owner=owner)
         return cls(dto=res)
 
     @classmethod
