@@ -98,22 +98,23 @@ class ReportFileWriter:
     def _display_msg(self):
         global SKIP_DISPLAY_MSG
 
+        # only display once per session, else skip
         if SKIP_DISPLAY_MSG:
             return None
         else:
-            SKIP_DISPLAY_MSG = False
+            SKIP_DISPLAY_MSG = True
 
         if is_jupyter():
             from IPython.display import Markdown, display
 
             display(
                 Markdown(
-                    "Thanks for using **Datapane**, to automate and securely share reports in your organization see [Datapane Enterprise](https://datapane.com/enterprise/)"
+                    "Thanks for using **Datapane**, to automate and securely share reports in your organization please visit [Datapane Enterprise](https://datapane.com/enterprise/)"
                 )
             )
         else:
             print(
-                "Thanks for using Datapane, to automate and securely share reports in your organization see Datapane Enterprise - https://datapane.com/enterprise/"
+                "Thanks for using Datapane, to automate and securely share reports in your organization please visit Datapane Enterprise - https://datapane.com/enterprise/"
             )
 
     def write(self, report_doc: str, path: str, report_type: ReportType):
@@ -282,14 +283,13 @@ class Report(DPObjectRef):
             path_uri = f"file://{osp.realpath(osp.expanduser(path))}"
             webbrowser.open_new_tab(path_uri)
 
-    def preview(self, width: int = 600, height: int = 500, standalone: bool = False) -> None:
+    def preview(self, width: int = 600, height: int = 500) -> None:
         """
         Preview the report inside your currently running Jupyter notebook
 
         Args:
             width: Width of the report preview in Jupyter (default: 600)
             height: Height of the report preview in Jupyter (default: 500)
-            standalone: Create a fully standalone HTML report with minimal external/network dependencies _(this can result in large files)
         """
         if is_jupyter():
             from IPython.display import IFrame
@@ -306,7 +306,7 @@ class Report(DPObjectRef):
                 shutil.copy(self._last_saved, tmpfile.name)
             else:
                 # Else save directly to tmp file
-                self.save(path=tmpfile.name, standalone=standalone)
+                self.save(path=tmpfile.name)
             self._tmp_report = tmpfile.file
 
             # NOTE - iframe must be relative path
